#! /bin/sh
#  Espresso local deployment module.
# 
#  Copyright(c) 2011 Panacoda GmbH. All rights reserved.
#  This file is licensed under the MIT license.
# 
#  Example usage:
#    #! /bin/sh
#    targetPath=quux # name of the target directory to deploy to
# 
#    export targetPath
# 
#    # deploy $PWD/bar into $PWD/quux
#    exec sh deploy.sh bar
#
set -euf

targetPath="${targetPath}"
sourcePath="${1-$sourcePath}"
if test "${debugLevel-0}" -gt 0; then
  rm_flags=-v
  cp_flags=-v
  mkdir_flags=-v
fi

targetPath_was_generated_by_Espresso() {
  head -n 2 "$targetPath/index.html" |
  tail -n 1 |
  grep -q '^<!-- This file was generated by Espresso version [0-9.]* -->$'
}

echo

# Remove targetPath path if it exists and we generated it
if test -e "$targetPath"; then
  if targetPath_was_generated_by_Espresso; then
    rm ${rm_flags-} -R "$targetPath"
  else
    exec >&2
    echo "Error: target path '$targetPath' exists but was not generated by Espresso"
    exit 23
  fi
fi

# Create targetPath
mkdir ${mkdir_flags-} -p "`dirname "$targetPath"`"
cp ${cp_flags-} -a "$sourcePath" "$targetPath"
